==> landtax-1.0.0-20160602.090753-7-sources.jar: cn/gtmap/landtax/model/query/DictTreeGrid.java <==
package cn.gtmap.landtax.model.query;

/**
 */
public class DictTreeGrid {
    private String name;
    private String zs;
    private String ycl;
    private String wcl;
    private String cll;
    private String xzqdm;
    private String state = "closed";// open,closed
    private String iconCls;

    private String dwdm;
    private String dwmc;
    private String ypp;
    private String zdpp;
    private String rgpp;
    private String wgjs;
    private String gjzs;
    private String ppl;



    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getZs() {
        return zs;
    }

    public void setZs(String zs) {
        this.zs = zs;
    }

    public String getYcl() {
        return ycl;
    }

    public void setYcl(String ycl) {
        this.ycl = ycl;
    }

    public String getWcl() {
        return wcl;
    }

    public void setWcl(String wcl) {
        this.wcl = wcl;
    }

    public String getCll() {
        return cll;
    }

    public void setCll(String cll) {
        this.cll = cll;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }


    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getIconCls() {
        return iconCls;
    }

    public void setIconCls(String iconCls) {
        this.iconCls = iconCls;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getYpp() {
        return ypp;
    }

    public void setYpp(String ypp) {
        this.ypp = ypp;
    }

    public String getZdpp() {
        return zdpp;
    }

    public void setZdpp(String zdpp) {
        this.zdpp = zdpp;
    }

    public String getRgpp() {
        return rgpp;
    }

    public void setRgpp(String rgpp) {
        this.rgpp = rgpp;
    }

    public String getWgjs() {
        return wgjs;
    }

    public void setWgjs(String wgjs) {
        this.wgjs = wgjs;
    }

    public String getPpl() {
        return ppl;
    }

    public void setPpl(String ppl) {
        this.ppl = ppl;
    }

    public String getGjzs() {
        return gjzs;
    }

    public void setGjzs(String gjzs) {
        this.gjzs = gjzs;
    }

    public String getDwmc() {
        return dwmc;
    }

    public void setDwmc(String dwmc) {
        this.dwmc = dwmc;
    }
}

==> landtax-1.0.0-20161009.022418-24-sources.jar: cn/gtmap/landtax/model/query/DictTreeGrid.java <==
package cn.gtmap.landtax.model.query;

/**
 */
public class DictTreeGrid {
    private String name;
    private String zs;
    private String ycl;
    private String wcl;
    private String cll;
    private String xzqdm;
    private String state = "closed";// open,closed
    private String iconCls;

    private String dwdm;
    private String dwmc;
    private String ypp;
    private String zdpp;
    private String rgpp;
    private String hcpp;
    private String wgjs;
    private String gjzs;
    private String ppl;



    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getZs() {
        return zs;
    }

    public void setZs(String zs) {
        this.zs = zs;
    }

    public String getYcl() {
        return ycl;
    }

    public void setYcl(String ycl) {
        this.ycl = ycl;
    }

    public String getWcl() {
        return wcl;
    }

    public void setWcl(String wcl) {
        this.wcl = wcl;
    }

    public String getCll() {
        return cll;
    }

    public void setCll(String cll) {
        this.cll = cll;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }


    public String getState() {
        return state;
    }

    public void setState(String state) {
        this.state = state;
    }

    public String getIconCls() {
        return iconCls;
    }

    public void setIconCls(String iconCls) {
        this.iconCls = iconCls;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getYpp() {
        return ypp;
    }

    public void setYpp(String ypp) {
        this.ypp = ypp;
    }

    public String getZdpp() {
        return zdpp;
    }

    public void setZdpp(String zdpp) {
        this.zdpp = zdpp;
    }

    public String getRgpp() {
        return rgpp;
    }

    public void setRgpp(String rgpp) {
        this.rgpp = rgpp;
    }

    public String getHcpp() {
        return hcpp;
    }

    public void setHcpp(String hcpp) {
        this.hcpp = hcpp;
    }

    public String getWgjs() {
        return wgjs;
    }

    public void setWgjs(String wgjs) {
        this.wgjs = wgjs;
    }

    public String getPpl() {
        return ppl;
    }

    public void setPpl(String ppl) {
        this.ppl = ppl;
    }

    public String getGjzs() {
        return gjzs;
    }

    public void setGjzs(String gjzs) {
        this.gjzs = gjzs;
    }

    public String getDwmc() {
        return dwmc;
    }

    public void setDwmc(String dwmc) {
        this.dwmc = dwmc;
    }
}
